@@ -47,22 +47,20 @@ update_station_list <- function() {
     isd_history <-
       fread("https://www1.ncdc.noaa.gov/pub/data/noaa/isd-history.csv")
 
+    # pad WBAN where necessary
+    isd_history[, WBAN := sprintf("%05d", WBAN)]
+
     # add STNID column
     isd_history[, STNID := paste(USAF, WBAN, sep = "-")]
     setcolorder(isd_history, "STNID")
     setnames(isd_history, "STATION NAME", "NAME")
 
-    # drop stations not in GSOD data
-    isd_history[, STNID_len := nchar(STNID)]
-    isd_history <- subset(isd_history, STNID_len == 12)
-
     # remove stations where LAT or LON is NA
     isd_history <- stats::na.omit(isd_history, cols = c("LAT", "LON"))
 
     # remove extra columns
-    isd_history[, c("USAF", "WBAN", "ICAO", "ELEV(M)", "STNID_len") := NULL]
+    isd_history[, c("USAF", "WBAN", "ICAO") := NULL]
 
-    # add STNID column
     isd_history <-
       isd_history[setDT(countrycode::codelist), on = c("CTRY" = "fips")]
 
@@ -71,6 +69,7 @@ update_station_list <- function() {
       "NAME",
       "LAT",
       "LON",
+      "ELEV(M)",
       "CTRY",
       "STATE",
       "BEGIN",
@@ -85,16 +84,16 @@ update_station_list <- function() {
     isd_history[isd_history == -999.9] <- NA
     isd_history <-
       isd_history[!is.na(isd_history$LAT) &
-                        !is.na(isd_history$LON), ]
+                    !is.na(isd_history$LON), ]
     isd_history <-
       isd_history[isd_history$LAT != 0 &
-                        isd_history$LON != 0, ]
+                    isd_history$LON != 0, ]
     isd_history <-
       isd_history[isd_history$LAT > -90 &
-                        isd_history$LAT < 90, ]
+                    isd_history$LAT < 90, ]
     isd_history <-
       isd_history[isd_history$LON > -180 &
-                        isd_history$LON < 180, ]
+                    isd_history$LON < 180, ]
 
     # set colnames to upper case
     names(isd_history) <- toupper(names(isd_history))
@@ -106,16 +105,14 @@ update_station_list <- function() {
     isd_history[, COUNTRY_NAME := toupper(COUNTRY_NAME)]
 
     # set key for joins when processing CSV files
-    setkeyv(isd_history, "STNID")
+    setkeyv(isd_history, "STNID")[]
 
     # write rda file to disk for use with GSODR package
     fname <-
       system.file("extdata", "isd_history.rda", package = "GSODR")
-    save(
-      isd_history,
-      file = fname,
-      compress = "bzip2"
-    )
+    save(isd_history,
+         file = fname,
+         compress = "bzip2")
   },
 
   error = function(cond) {
